@@ -3,6 +3,7 @@
 import abc
 import csv
 import json
+import re
 from dataclasses import dataclass, field
 from typing import Any, Callable, Dict, Generator, Iterable, List, Literal, Optional
 from urllib.parse import urlencode
@@ -51,10 +52,11 @@ tms_settings = TMSSettings()
 mvt_settings = MVTSettings()
 features_settings = FeaturesSettings()
 
-DEFAULT_TEMPLATES = Jinja2Templates(
-    directory="",
-    loader=jinja2.ChoiceLoader([jinja2.PackageLoader(__package__, "templates")]),
-)  # type:ignore
+
+jinja2_env = jinja2.Environment(
+    loader=jinja2.ChoiceLoader([jinja2.PackageLoader(__package__, "templates")])
+)
+DEFAULT_TEMPLATES = Jinja2Templates(env=jinja2_env)
 
 
 COMMON_CONFORMS = [
@@ -118,6 +120,9 @@ def create_html_response(
 ) -> _TemplateResponse:
     """Create Template response."""
     urlpath = request.url.path
+    if root_path := request.app.root_path:
+        urlpath = re.sub(r"^" + root_path, "", urlpath)
+
     crumbs = []
     baseurl = str(request.base_url).rstrip("/")
 
@@ -134,9 +139,9 @@ def create_html_response(
         baseurl += router_prefix
 
     return templates.TemplateResponse(
-        f"{template_name}.html",
-        {
-            "request": request,
+        request,
+        name=f"{template_name}.html",
+        context={
             "response": orjson.loads(data),
             "template": {
                 "api_root": baseurl,
@@ -409,6 +414,7 @@ class OGCFeaturesFactory(EndpointsFactory):
                     }
                 },
             },
+            tags=["OGC Features API"],
         )
         def collections(
             request: Request,
@@ -529,6 +535,7 @@ class OGCFeaturesFactory(EndpointsFactory):
                     }
                 },
             },
+            tags=["OGC Features API"],
         )
         def collection(
             request: Request,
@@ -616,6 +623,7 @@ class OGCFeaturesFactory(EndpointsFactory):
                     }
                 },
             },
+            tags=["OGC Features API"],
         )
         def queryables(
             request: Request,
@@ -662,6 +670,7 @@ class OGCFeaturesFactory(EndpointsFactory):
                     "model": model.Items,
                 },
             },
+            tags=["OGC Features API"],
         )
         async def items(  # noqa: C901
             request: Request,
@@ -749,19 +758,27 @@ class OGCFeaturesFactory(EndpointsFactory):
                 MediaType.json,
                 MediaType.ndjson,
             ):
-                rows = (
-                    {
-                        k: v
-                        for k, v in {
+                if any(
+                    [f.get("geometry", None) is not None for f in item_list["items"]]
+                ):
+                    rows = (
+                        {
                             "collectionId": collection.id,
                             "itemId": f.get("id"),
                             **f.get("properties", {}),
                             "geometry": f.get("geometry", None),
-                        }.items()
-                        if v is not None
-                    }
-                    for f in item_list["items"]
-                )
+                        }
+                        for f in item_list["items"]
+                    )
+                else:
+                    rows = (
+                        {
+                            "collectionId": collection.id,
+                            "itemId": f.get("id"),
+                            **f.get("properties", {}),
+                        }
+                        for f in item_list["items"]
+                    )
 
                 # CSV Response
                 if output_type == MediaType.csv:
@@ -918,6 +935,7 @@ class OGCFeaturesFactory(EndpointsFactory):
                     "model": model.Item,
                 },
             },
+            tags=["OGC Features API"],
         )
         async def item(
             request: Request,
@@ -1150,6 +1168,7 @@ class OGCTilesFactory(EndpointsFactory):
                     },
                 },
             },
+            tags=["OGC Tiles API"],
         )
         async def tilematrixsets(
             request: Request,
@@ -1202,6 +1221,7 @@ class OGCTilesFactory(EndpointsFactory):
                     },
                 },
             },
+            tags=["OGC Tiles API"],
         )
         async def tilematrixset(
             request: Request,
@@ -1248,6 +1268,7 @@ class OGCTilesFactory(EndpointsFactory):
             },
             summary="Retrieve a list of available vector tilesets for the specified collection.",
             operation_id=".collection.vector.getTileSetsList",
+            tags=["OGC Tiles API"],
         )
         async def collection_tileset_list(
             request: Request,
@@ -1331,6 +1352,7 @@ class OGCTilesFactory(EndpointsFactory):
             responses={200: {"content": {MediaType.json.value: {}}}},
             summary="Retrieve the vector tileset metadata for the specified collection and tiling scheme (tile matrix set).",
             operation_id=".collection.vector.getTileSet",
+            tags=["OGC Tiles API"],
         )
         async def collection_tileset(
             request: Request,
@@ -1442,12 +1464,14 @@ class OGCTilesFactory(EndpointsFactory):
             response_class=Response,
             responses={200: {"content": {MediaType.mvt.value: {}}}},
             operation_id=".collection.vector.getTileTms",
+            tags=["OGC Tiles API"],
         )
         @self.router.get(
             "/collections/{collectionId}/tiles/{z}/{x}/{y}",
             response_class=Response,
             responses={200: {"content": {MediaType.mvt.value: {}}}},
             operation_id=".collection.vector.getTile",
+            tags=["OGC Tiles API"],
         )
         async def collection_get_tile(
             request: Request,
@@ -1521,6 +1545,7 @@ class OGCTilesFactory(EndpointsFactory):
             response_model_exclude_none=True,
             response_class=ORJSONResponse,
             operation_id=".collection.vector.getTileJSONTms",
+            tags=["OGC Tiles API"],
         )
         @self.router.get(
             "/collections/{collectionId}/tilejson.json",
@@ -1529,6 +1554,7 @@ class OGCTilesFactory(EndpointsFactory):
             response_model_exclude_none=True,
             response_class=ORJSONResponse,
             operation_id=".collection.vector.getTileJSON",
+            tags=["OGC Tiles API"],
         )
         async def collection_tilejson(
             request: Request,
@@ -1620,6 +1646,7 @@ class OGCTilesFactory(EndpointsFactory):
             response_model_exclude_none=True,
             response_class=ORJSONResponse,
             operation_id=".collection.vector.getStyleJSONTms",
+            tags=["OGC Tiles API"],
         )
         @self.router.get(
             "/collections/{collectionId}/style.json",
@@ -1628,6 +1655,7 @@ class OGCTilesFactory(EndpointsFactory):
             response_model_exclude_none=True,
             response_class=ORJSONResponse,
             operation_id=".collection.vector.getStyleJSON",
+            tags=["OGC Tiles API"],
         )
         async def collection_stylejson(
             request: Request,
@@ -1801,9 +1829,9 @@ class OGCTilesFactory(EndpointsFactory):
                     tilejson_url += f"?{urlencode(request.query_params._list)}"
 
                 return self.templates.TemplateResponse(
+                    request,
                     name="map.html",
                     context={
-                        "request": request,
                         "tilejson_endpoint": tilejson_url,
                     },
                     media_type="text/html",
@@ -1849,7 +1877,7 @@ class Endpoints(EndpointsFactory):
             # We do not want `/` and `/conformance` from the factory
             with_common=False,
         )
-        self.router.include_router(self.ogc_features.router, tags=["OGC Features API"])
+        self.router.include_router(self.ogc_features.router)
 
         self.ogc_tiles = OGCTilesFactory(
             collection_dependency=self.collection_dependency,
@@ -1860,4 +1888,4 @@ class Endpoints(EndpointsFactory):
             # We do not want `/` and `/conformance` from the factory
             with_common=False,
         )
-        self.router.include_router(self.ogc_tiles.router, tags=["OGC Tiles API"])
+        self.router.include_router(self.ogc_tiles.router)
